==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridClipboardOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardOptionsDescription } from "./WebGridClipboardOptionsDescription";
/**
 * @hidden
 */
export let WebGridClipboardOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridClipboardOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridClipboardOptionsDescriptionMetadata.a == null) {
                WebGridClipboardOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridClipboardOptionsDescriptionMetadata.c(WebGridClipboardOptionsDescriptionMetadata.a);
            }
            if (a.j(WebGridClipboardOptionsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridClipboardOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridClipboardOptions");
        }
        static d(a) {
            WebGridClipboardOptionsDescriptionMetadata.b(a);
            a.aa("WebGridClipboardOptions", () => new WebGridClipboardOptionsDescription());
            a.z("WebGridClipboardOptions", WebGridClipboardOptionsDescriptionMetadata.a);
        }
    }
    WebGridClipboardOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridClipboardOptionsDescriptionMetadata, 'WebGridClipboardOptionsDescriptionMetadata');
    WebGridClipboardOptionsDescriptionMetadata.a = null;
    return WebGridClipboardOptionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridClipboardOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridClipboardOptionsDescription } from "./WebGridClipboardOptionsDescription";
/**
 * @hidden
 */
export let WebGridClipboardOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridClipboardOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridClipboardOptionsDescriptionMetadata.a == null) {
                WebGridClipboardOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridClipboardOptionsDescriptionMetadata.c(WebGridClipboardOptionsDescriptionMetadata.a);
            }
            if (a.k(WebGridClipboardOptionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridClipboardOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridClipboardOptions");
        }
        static d(a) {
            WebGridClipboardOptionsDescriptionMetadata.b(a);
            a.ac("WebGridClipboardOptions", () => new WebGridClipboardOptionsDescription());
            a.ab("WebGridClipboardOptions", WebGridClipboardOptionsDescriptionMetadata.a);
        }
    }
    WebGridClipboardOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridClipboardOptionsDescriptionMetadata, 'WebGridClipboardOptionsDescriptionMetadata');
    WebGridClipboardOptionsDescriptionMetadata.a = null;
    return WebGridClipboardOptionsDescriptionMetadata;
})();
